@@ -21,6 +21,7 @@ import napari
 
 from apoc import PredefinedFeatureSet, ObjectSegmenter, PixelClassifier, ProbabilityMapper
 from napari_tools_menu import register_dock_widget
+from ._surface_vertex_classifier import SurfaceVertexClassifierWidget
 
 @register_dock_widget(menu="Segmentation / labeling > Object segmentation (APOC)")
 class ObjectSegmentation(QWidget):
@@ -100,7 +101,7 @@ class ObjectSegmentation(QWidget):
         #feature_selection_button = QPushButton("Select features")
         #training_widget.layout().addWidget(feature_selection_button)
 
-        self.feature_selector = FeatureSelector(PredefinedFeatureSet.v070.value)
+        self.feature_selector = FeatureSelector(self, PredefinedFeatureSet.v070.value)
         collabsible.addWidget(self.feature_selector)
         collabsible.setDuration(0)
         set_border(collabsible)
@@ -119,7 +120,7 @@ class ObjectSegmentation(QWidget):
         num_trees_spinner = QSpinBox()
         num_trees_spinner.setMinimum(1)
         num_trees_spinner.setMaximum(1000)
-        num_trees_spinner.setValue(10)
+        num_trees_spinner.setValue(100)
         num_trees_spinner.setToolTip("The more image channels and features you selected, the more trees should be used to retrieve a reliable and robust classifier. The more trees, the longer processing will take.")
 
         # Max Depth / Number of ensembles
@@ -151,6 +152,12 @@ class ObjectSegmentation(QWidget):
                 warnings.warn("Selected images and annotation must have the same dimensionality and size!")
                 return
 
+            if len(self.get_selected_images()) == 0:
+                warnings.warn("Please select image/channel[s] to train on.")
+                return
+
+            first_image_layer = self.get_selected_images()[0]
+
             self.train(
                 self.get_selected_images_data(),
                 self.get_selected_annotation_data(),
@@ -160,6 +167,7 @@ class ObjectSegmentation(QWidget):
                 num_trees_spinner.value(),
                 str(filename_edit.value.absolute()).replace("\\", "/").replace("//", "/"),
                 show_classifier_statistics_checkbox.isChecked(),
+                first_image_layer.scale
             )
         button.clicked.connect(train_clicked)
         training_widget.layout().addWidget(button)
@@ -188,9 +196,12 @@ class ObjectSegmentation(QWidget):
                                    "segmenter = " + str(self.classifier_class.__name__) + "(opencl_filename='" + filename + "')\n\n" +
                                    "result = segmenter.predict(image=" + image_names + ")")
 
+            first_image_layer = self.get_selected_images()[0]
+
             self.predict(
                 self.get_selected_images_data(),
-                filename
+                filename,
+                first_image_layer.scale
             )
 
         button.clicked.connect(predict_clicked)
@@ -240,6 +251,7 @@ class ObjectSegmentation(QWidget):
               num_trees,
               filename,
               show_classifier_statistics,
+              scale=None,
     ):
         print("train " + str(self.classifier_class.__name__))
         print("num images", len(images))
@@ -282,14 +294,14 @@ class ObjectSegmentation(QWidget):
         print("Applying / prediction done.")
 
         short_filename = filename.split("/")[-1]
-        self._add_to_viewer("Result of " + short_filename, result)
+        self._add_to_viewer("Result of " + short_filename, result, scale)
 
         if show_classifier_statistics and self.viewer is not None:
             table = QTableWidget()
             update_model_analysis(table, classifier)
             self.viewer.window.add_dock_widget(table)
 
-    def _add_to_viewer(self, name, data):
+    def _add_to_viewer(self, name, data, scale=None):
         try:
             self.viewer.layers[name].data = data.astype(int)
             self.viewer.layers[name].visible = True
@@ -297,9 +309,9 @@ class ObjectSegmentation(QWidget):
             if self.classifier_class == ProbabilityMapper:
                 self.viewer.add_image(data, name=name)
             else:
-                self.viewer.add_labels(data.astype(int), name=name)
+                self.viewer.add_labels(data.astype(int), name=name, scale=scale)
 
-    def predict(self, images, filename):
+    def predict(self, images, filename, scale=None):
         print("predict")
         print("num images", len(images))
         print("file", filename)
@@ -320,7 +332,7 @@ class ObjectSegmentation(QWidget):
 
         short_filename = filename.split("/")[-1]
 
-        self._add_to_viewer("Result of " + short_filename, result)
+        self._add_to_viewer("Result of " + short_filename, result, scale=scale)
 
     def update_memory_consumption(self):
         number_of_pixels = np.sum(tuple([np.prod(i.shape) for i in self.get_selected_images_data()]))
@@ -454,7 +466,7 @@ def update_table_gui(statistics_table, table, minimum_value=0.0, maximum_value=1
                 item.setBackground(brush.color())
                 item.setForeground(QColor(0,0,0,255))
             statistics_table.setItem(i, j, item)
-        statistics_table.setColumnWidth(i, 40)
+        statistics_table.setColumnWidth(i, 60)
 
 
 
@@ -463,15 +475,15 @@ class SemanticSegmentation(ObjectSegmentation):
     def __init__(self, napari_viewer):
         super().__init__(napari_viewer, classifier_class=PixelClassifier)
 
-@register_dock_widget(menu="Filtering > Probability mapper (APOC)")
+@register_dock_widget(menu="Filtering > Probability Mapper (APOC)")
 class ProbabilityMapping(ObjectSegmentation):
     def __init__(self, napari_viewer):
         super().__init__(napari_viewer, classifier_class=ProbabilityMapper)
 
 
 class FeatureSelector(QWidget):
-    def __init__(self, feature_definition:str):
-        super().__init__()
+    def __init__(self, parent, feature_definition:str):
+        super().__init__(parent)
         self.setLayout(QVBoxLayout())
         self.feature_definition = " " + feature_definition.lower() + " "
 
@@ -544,7 +556,8 @@ def napari_experimental_provide_dock_widget():
     # you can return either a single widget, or a sequence of widgets
     from ._function import Train_object_classifier
     from ._custom_table_row_classifier import CustomObjectClassifierWidget
-    return [ObjectSegmentation, SemanticSegmentation, Train_object_classifier, CustomObjectClassifierWidget]
+    from ._object_merger import Train_object_merger
+    return [ObjectSegmentation, SemanticSegmentation, Train_object_classifier, CustomObjectClassifierWidget, Train_object_merger]
 
 
 def set_border(widget:QWidget, spacing=2, margin=0):
