@@ -9,14 +9,14 @@ def test_training(make_napari_viewer):
         Train_object_segmentation_from_visible_image_layers,\
         Train_pixel_classifier_from_visible_image_layers,\
         Connected_component_labeling,\
-        Apply_object_classification,\
         Apply_pixel_classification,\
         Apply_object_segmentation,\
         Apply_probability_mapper,\
         Apply_object_segmentation_to_visible_image_layers,\
         Apply_pixel_classification_to_visible_image_layers
+        # Apply_object_classification,\
+
     import apoc
-    Connected_component_labeling
 
     image = np.asarray([
         [0,0,1,1],
@@ -29,7 +29,7 @@ def test_training(make_napari_viewer):
     viewer.add_image(image)
     viewer.add_labels(labels)
 
-    Train_object_classifier()(image, labels, labels)
+    #Train_object_classifier()(image, labels, labels)
     Train_object_classifier()(image, labels, labels, "ObjectClassifier.cl", 2, 10, True, True, True, True, True, True, True, True, True, True, True, True, True)
     Train_pixel_classifier(image, labels, featureset=apoc.PredefinedFeatureSet.custom, custom_features="original")
     Train_pixel_classifier(image, labels)
@@ -40,7 +40,7 @@ def test_training(make_napari_viewer):
     Train_pixel_classifier_from_visible_image_layers(labels, napari_viewer=viewer)
     Connected_component_labeling(labels)
     Connected_component_labeling(labels, fill_gaps_between_labels=False)
-    Apply_object_classification(image, labels)
+    #Apply_object_classification(image, labels)
     Apply_pixel_classification(image)
     #Apply_object_segmentation(image)
     #Apply_probability_mapper(image)
@@ -80,3 +80,20 @@ def test_probability_mapper():
     import apoc
     Train_probability_mapper(image, labels, model_filename="file2.cl", featureset=apoc.PredefinedFeatureSet.custom, custom_features="original")
     Apply_probability_mapper(image, model_filename="file2.cl")
+
+def test_annotation_to_cluster_id():
+    import pyclesperanto_prototype as cle
+    from napari_accelerated_pixel_and_object_classification._function import annotation_to_cluster_id
+
+    labels = cle.push(np.asarray([
+        [1, 2],
+        [3, 3]]).astype(int))
+
+    annotation = cle.push(np.asarray([
+        [0, 1],
+        [2, 1]]).astype(int))
+
+    reference = [0, 1, 2]
+    result = annotation_to_cluster_id(labels, annotation)["ANNOTATION_CLUSTER_ID"]
+
+    assert np.array_equal(reference, result)
\ No newline at end of file
